#ifndef UsrYield_h
#define UsrYield_h

/////////////////////////////////////////////////
//
//  UsrYield
//
//  A class to read FLUKA's USRYIELD output
//  contact: Konstantin.Batkov@pi.infn.it
//
/////////////////////////////////////////////////

#include "ReadFluka.h"
#include <TObject.h>
#include <TH1.h>
#include <TObjArray.h>

class UsrYield : public ReadFluka, public TObject {
 private:
  Float_t                        fWEIPRI;          // weight of primary particle
  Int_t                          fIJUSYL;          // projectile identity
  Int_t                          fJTUSYL;          // target identity
  Float_t                        fPUSRYL;          // momentum of projectile to be used to define (possible) Lorentz transformations, Feynman X etc.
  Float_t                        fSQSUYL;          // cms energy for Lorentz transformation
  Float_t                        fUUSRYL;          // laboratory projectile cosX-direction
  Float_t                        fVUSRYL;          // laboratory projectile cosY-direction
  Float_t                        fWUSRYL;          // laboratory projectile cosZ-direction

  Int_t                          fMY;              // id-number of the yield detector
  Char_t                        *fTITUYL;          // detector name (SDUM in first card)

  Int_t                          fITUSYL;          // type of binning = WHAT(1) of first card = ie + ia*100
  Int_t                          fie;              // ie, first physical quantity to be scored
  Int_t                          fia;              // ia, second physical quantity to be scored

  Int_t                          fIXUSYL;          // cross section kind, ixa + ixm*100
  Int_t                          fixa;             // the kind of yield or cross-section desired
  Int_t                          fixm;             // the target material (if needed in order to calculate a cross-section, otherwise ixm = 0)


  Int_t                          fIDUSYL;          // particle scored = WHAT(2) of first card
  Int_t                          fNR1UYL;          // first region = WHAT(4) of first card
  Int_t                          fNR2UYL;          // second region = WHAT(5) of first card
  Float_t                        fUSNRYL;          // user normalization factor
  Float_t                        fSGUSYL;          // adopted cross section (if any)
  Bool_t                         fLLNUYL;          // no low-energy neutron scoring if false, yes if true
  Float_t                        fEYLLOW;          // minimum energy (GeV) (WHAT(2) of 2nd card: may be re-defined if low-energy neutrons are scored
  Float_t                        fEYLHGH;          // maximum energy (GeV) (WHAT(1) of 2nd card)
  Int_t                          fNEYLBN;          // number of energy intervals (re-defined by the program if low-energy neutrons are scored)
  Float_t                        fDEYLBN;          // energy bin width (GeV) if linear in energy or referring to a low-energy neutron energy group, otherwise ratio between upper and lower edge of energy intervals
  Float_t                        fAYLLOW;          // minimum angle (steradian) (WHAT(5) of 2nd card)
  Float_t                        fAYLHGH;          // maximum angle (steradian) (WHAT(4) of 2nd card)

  Int_t                          fIGMUYL;          //  maximum low-energy neutron group to be scored
  Float_t                       *fENGMAX;          //  upper energies (GeV) of the neutron groups

  Float_t                       *fSCORED;          // scored results [sr^{-1}*GeV^{-1}]
  Int_t                          fINTERV;          // number of intervals in fSCORED = fNEYLBN + fIGMUYL

  Bool_t                         fIsReadHeader;
  void                           ReadHeader();     // read the header
  void                           Reset();

  TObjArray                      fHists;          // list of all histograms
  void                           MakeHist();
 public:
  UsrYield(const char *fname);
  virtual ~UsrYield();

  Bool_t                         Read();
  Float_t                        GetMin1() const {return fEYLLOW;}
  Float_t                        GetMax1() const {return fEYLHGH;}
  Float_t                        GetMin2() const {return fAYLLOW;}
  Float_t                        GetMax2() const {return fAYLHGH;}
  Int_t                          GetNbins1() const {return fNEYLBN;}

  const Float_t                 *GetScored() const {return fSCORED;}
  Float_t                        GetScored(Int_t bin) const {return bin < fINTERV ? fSCORED[bin] : -1;}

  UInt_t                         GetUpstreamRegion() const {return fNR1UYL > 0 ? fNR1UYL : 0;}
  UInt_t                         GetDownstreamRegion() const {return fNR2UYL > 0 ? fNR2UYL : 0;}
  Float_t                        GetUserNorm() const {return fUSNRYL;}

  const Char_t                  *GetTitle() const {return fTITUYL;}
  const Char_t                  *GetXTitle() const;
  const Char_t                  *GetYTitle() const;
  Int_t                          GetTypeOfScoredParticles() const {return fIDUSYL;}
  const Char_t                  *GetNameOfScoredParticles() const;

  TH1F *GetHistogram() const { return (TH1F*)fHists[fMY-1]; }
  TObjArray *GetHistograms() {return &fHists; }
	  
};

#endif
